==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERCONTRACTADJUSTMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERCONTRACTADJUSTMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERCONTRACTADJUSTMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERCONTRACTADJUSTMENTID_Type", propOrder = {
    "adjustmentcode"
})
public class CUSTOMERCONTRACTADJUSTMENTID_Type {

    @XmlElement(name = "ADJUSTMENTCODE", required = true)
    protected String adjustmentcode;

    /**
     * Obtient la valeur de la propriété adjustmentcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getADJUSTMENTCODE() {
        return adjustmentcode;
    }

    /**
     * Définit la valeur de la propriété adjustmentcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setADJUSTMENTCODE(String value) {
        this.adjustmentcode = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERCONTRACTADJUSTMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERCONTRACTADJUSTMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERCONTRACTADJUSTMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADJUSTMENTCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERCONTRACTADJUSTMENTID_Type", propOrder = {
    "adjustmentcode"
})
public class CUSTOMERCONTRACTADJUSTMENTID_Type {

    @XmlElement(name = "ADJUSTMENTCODE", required = true)
    protected String adjustmentcode;

    /**
     * Gets the value of the adjustmentcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getADJUSTMENTCODE() {
        return adjustmentcode;
    }

    /**
     * Sets the value of the adjustmentcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setADJUSTMENTCODE(String value) {
        this.adjustmentcode = value;
    }

}
